import { BrowserRouter as Router, Routes, Route, Navigate } from 'react-router-dom';
import { AuthProvider, useAuth } from './contexts/AuthContext';
import Layout from './components/Layout';
import ProtectedRoute from './components/ProtectedRoute';
import ApiTester from './components/ApiTester';

// Auth Pages
import Login from './pages/auth/Login';

// Dashboard
import Dashboard from './pages/dashboard/Dashboard';

// Companies
import Companies from './pages/companies/Companies';

// Users
import Users from './pages/users/Users';

// Products
import Products from './pages/products/Products';

import './App.css';

function App() {
  return (
    <Router>
      <AuthProvider>
        <AppRoutes />
      </AuthProvider>
    </Router>
  );
}

// Separate component to use auth context after it's properly initialized
function AppRoutes() {
  const { currentUser, loading } = useAuth();
  console.log('Auth state in AppRoutes:', { 
    currentUser: currentUser ? { 
      id: currentUser._id,
      email: currentUser.email, 
      role: currentUser.role 
    } : null, 
    loading 
  });

  // Wait for auth to initialize before rendering routes
  if (loading) {
    return <div className="flex justify-center items-center h-screen">Loading authentication...</div>;
  }
  
  return (
    <Routes>
      {/* Public routes */}
      <Route path="/login" element={
        currentUser ? <Navigate to="/dashboard" replace /> : <Login />
      } />
      <Route path="/api-test" element={<ApiTester />} />
      
      {/* Debug route - accessible without authentication */}
      <Route path="/dashboard-public" element={<Dashboard />} />
      
      {/* Protected routes */}
      <Route element={<ProtectedRoute allowedRoles={['superadmin', 'companyadmin', 'employer']} />}>
        <Route element={<Layout />}>
          <Route path="/dashboard" element={<Dashboard />} />
          <Route path="/products" element={<Products />} />
          
          {/* Admin-only routes */}
          <Route element={<ProtectedRoute allowedRoles={['superadmin', 'companyadmin']} />}>
            <Route path="/users" element={<Users />} />
          </Route>
          
          <Route element={<ProtectedRoute allowedRoles={['superadmin']} />}>
            <Route path="/companies" element={<Companies />} />
          </Route>
        </Route>
      </Route>
      
      {/* Redirect to dashboard if logged in, otherwise to login */}
      <Route path="/" element={
        <Navigate to={currentUser ? "/dashboard" : "/login"} replace />
      } />
      
      <Route path="*" element={
        <Navigate to={currentUser ? "/dashboard" : "/login"} replace />
      } />
    </Routes>
  );
}

export default App;
