import { useState, useEffect } from 'react';
import { testHealthEndpoint, testAuthEndpoint, testProductsEndpoint } from '../utils/apiTest';

const ApiTester = () => {
  const [healthStatus, setHealthStatus] = useState({ loading: true, data: null, error: null });
  const [authStatus, setAuthStatus] = useState({ loading: false, data: null, error: null });
  const [productsStatus, setProductsStatus] = useState({ loading: false, data: null, error: null });
  const [credentials, setCredentials] = useState({ email: 'admin@example.com', password: 'password123' });

  useEffect(() => {
    // Test health endpoint on component mount
    const checkHealth = async () => {
      setHealthStatus({ loading: true, data: null, error: null });
      const result = await testHealthEndpoint();
      if (result.success) {
        setHealthStatus({ loading: false, data: result.data, error: null });
      } else {
        setHealthStatus({ loading: false, data: null, error: result.error });
      }
    };

    checkHealth();
  }, []);

  const handleAuthTest = async () => {
    setAuthStatus({ loading: true, data: null, error: null });
    const result = await testAuthEndpoint(credentials);
    if (result.success) {
      setAuthStatus({ loading: false, data: result.data, error: null });
      // If auth successful, test products endpoint with the token
      if (result.data.token) {
        await handleProductsTest(result.data.token);
      }
    } else {
      setAuthStatus({ loading: false, data: null, error: result.error });
    }
  };

  const handleProductsTest = async (token) => {
    setProductsStatus({ loading: true, data: null, error: null });
    const result = await testProductsEndpoint(token);
    if (result.success) {
      setProductsStatus({ loading: false, data: result.data, error: null });
    } else {
      setProductsStatus({ loading: false, data: null, error: result.error });
    }
  };

  const handleInputChange = (e) => {
    const { name, value } = e.target;
    setCredentials(prev => ({ ...prev, [name]: value }));
  };

  return (
    <div className="p-6 max-w-4xl mx-auto bg-white rounded-lg shadow-md">
      <h2 className="text-2xl font-bold mb-6 text-gray-800">API Connection Tester</h2>
      
      {/* Health Endpoint Test */}
      <div className="mb-8 p-4 border rounded-lg">
        <h3 className="text-xl font-semibold mb-2 text-gray-700">Health Endpoint</h3>
        {healthStatus.loading ? (
          <p className="text-gray-600">Testing health endpoint...</p>
        ) : healthStatus.error ? (
          <div className="bg-red-50 p-3 rounded border border-red-200">
            <p className="text-red-600 font-medium">Error: {JSON.stringify(healthStatus.error)}</p>
          </div>
        ) : (
          <div className="bg-green-50 p-3 rounded border border-green-200">
            <p className="text-green-600 font-medium">Success: {JSON.stringify(healthStatus.data)}</p>
          </div>
        )}
      </div>
      
      {/* Auth Endpoint Test */}
      <div className="mb-8 p-4 border rounded-lg">
        <h3 className="text-xl font-semibold mb-2 text-gray-700">Authentication Endpoint</h3>
        <div className="mb-4">
          <div className="mb-3">
            <label className="block text-gray-700 mb-1">Email</label>
            <input 
              type="email" 
              name="email" 
              value={credentials.email} 
              onChange={handleInputChange}
              className="w-full px-3 py-2 border rounded-md"
            />
          </div>
          <div className="mb-3">
            <label className="block text-gray-700 mb-1">Password</label>
            <input 
              type="password" 
              name="password" 
              value={credentials.password} 
              onChange={handleInputChange}
              className="w-full px-3 py-2 border rounded-md"
            />
          </div>
          <button 
            onClick={handleAuthTest}
            className="bg-blue-500 text-white px-4 py-2 rounded-md hover:bg-blue-600"
            disabled={authStatus.loading}
          >
            {authStatus.loading ? 'Testing...' : 'Test Auth Endpoint'}
          </button>
        </div>
        
        {authStatus.loading ? (
          <p className="text-gray-600">Testing auth endpoint...</p>
        ) : authStatus.error ? (
          <div className="bg-red-50 p-3 rounded border border-red-200">
            <p className="text-red-600 font-medium">Error: {JSON.stringify(authStatus.error)}</p>
          </div>
        ) : authStatus.data && (
          <div className="bg-green-50 p-3 rounded border border-green-200">
            <p className="text-green-600 font-medium">Success: Authentication successful</p>
            <pre className="mt-2 text-sm bg-gray-50 p-2 rounded overflow-auto max-h-40">
              {JSON.stringify(authStatus.data, null, 2)}
            </pre>
          </div>
        )}
      </div>
      
      {/* Products Endpoint Test */}
      <div className="p-4 border rounded-lg">
        <h3 className="text-xl font-semibold mb-2 text-gray-700">Products Endpoint</h3>
        <p className="text-gray-600 mb-4">This test will run automatically after successful authentication.</p>
        
        {productsStatus.loading ? (
          <p className="text-gray-600">Testing products endpoint...</p>
        ) : productsStatus.error ? (
          <div className="bg-red-50 p-3 rounded border border-red-200">
            <p className="text-red-600 font-medium">Error: {JSON.stringify(productsStatus.error)}</p>
          </div>
        ) : productsStatus.data && (
          <div className="bg-green-50 p-3 rounded border border-green-200">
            <p className="text-green-600 font-medium">Success: Products retrieved</p>
            <pre className="mt-2 text-sm bg-gray-50 p-2 rounded overflow-auto max-h-40">
              {JSON.stringify(productsStatus.data, null, 2)}
            </pre>
          </div>
        )}
      </div>
    </div>
  );
};

export default ApiTester;
