import { createContext, useState, useEffect, useContext } from 'react';
import axios from 'axios';

const AuthContext = createContext();

export const useAuth = () => useContext(AuthContext);

export const AuthProvider = ({ children }) => {
  const [currentUser, setCurrentUser] = useState(null);
  const [token, setToken] = useState(localStorage.getItem('token'));
  const [loading, setLoading] = useState(true);

  // Configure axios defaults
  // When running in Docker with Nginx, we don't need to specify the full URL
  // as Nginx will handle the routing based on the path
  axios.defaults.baseURL = import.meta.env.VITE_API_URL || '';
  
  // Set auth token if it exists
  if (token) {
    axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
  }
  
  // Load user and set up authentication state
  useEffect(() => {
    console.log('AuthContext: Loading user from localStorage...');
    const loadUser = async () => {
      const token = localStorage.getItem('token');
      const savedUser = localStorage.getItem('user');
      
      if (token) {
        console.log('AuthContext: Token found in localStorage');
        axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
        
        if (savedUser) {
          try {
            console.log('AuthContext: User found in localStorage, parsing...');
            const parsedUser = JSON.parse(savedUser);
            console.log('AuthContext: User parsed successfully:', parsedUser);
            
            // Set user from localStorage immediately for better UX
            setCurrentUser(parsedUser);
          } catch (error) {
            console.error('AuthContext: Error parsing user from localStorage:', error);
            localStorage.removeItem('user');
          }
        }
        
        // Verify with server in the background
        try {
          const response = await axios.get('/api/auth/me');
          console.log('AuthContext: Server verification successful:', response.data);
          
          // The /api/auth/me endpoint returns { success: true, data: user }
          const userData = response.data.data || response.data;
          
          setCurrentUser(userData);
          localStorage.setItem('user', JSON.stringify(userData));
        } catch (error) {
          console.error('AuthContext: Server verification failed:', error);
          // If server verification fails, clear everything
          localStorage.removeItem('token');
          localStorage.removeItem('user');
          delete axios.defaults.headers.common['Authorization'];
          setCurrentUser(null);
        }
      } else {
        console.log('AuthContext: No token found in localStorage');
        setCurrentUser(null);
        delete axios.defaults.headers.common['Authorization'];
      }
      
      setLoading(false);
    };
    
    loadUser();
  }, []);

  // Login function
  const login = async (email, password) => {
    try {
      const res = await axios.post('/api/auth/login', { email, password });
      const { token: newToken, user } = res.data;
      
      console.log('Login successful:', { token: newToken, user });
      
      // Save token and user to localStorage
      localStorage.setItem('token', newToken);
      localStorage.setItem('user', JSON.stringify(user));
      
      // Set axios default header
      axios.defaults.headers.common['Authorization'] = `Bearer ${newToken}`;
      
      setToken(newToken);
      setCurrentUser(user);
      
      return user;
    } catch (error) {
      console.error('Login error:', error);
      throw error;
    }
  };

  // Logout function
  const logout = () => {
    localStorage.removeItem('token');
    localStorage.removeItem('user');
    delete axios.defaults.headers.common['Authorization'];
    setToken(null);
    setCurrentUser(null);
  };

  // Check if user has required role
  const hasRole = (requiredRoles) => {
    if (!currentUser) return false;
    
    if (Array.isArray(requiredRoles)) {
      return requiredRoles.includes(currentUser.role);
    }
    
    return currentUser.role === requiredRoles;
  };

  const value = {
    currentUser,
    token,
    loading,
    login,
    logout,
    hasRole
  };

  return (
    <AuthContext.Provider value={value}>
      {!loading && children}
    </AuthContext.Provider>
  );
};

export default AuthContext;
