import { useState, useEffect } from 'react';
import axios from 'axios';
import { useAuth } from '../../contexts/AuthContext';
import CompanyForm from './CompanyForm';

export default function Companies() {
  const { currentUser } = useAuth();
  const [companies, setCompanies] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [showForm, setShowForm] = useState(false);
  const [currentCompany, setCurrentCompany] = useState(null);

  // Fetch companies when component mounts
  useEffect(() => {
    fetchCompanies();
  }, []);

  const fetchCompanies = async () => {
    try {
      setLoading(true);
      const res = await axios.get('/api/companies');
      setCompanies(res.data.data);
      setError(null);
    } catch (error) {
      console.error('Error fetching companies:', error);
      setError('Failed to load companies');
    } finally {
      setLoading(false);
    }
  };

  const handleAddCompany = () => {
    setCurrentCompany(null);
    setShowForm(true);
  };

  const handleEditCompany = (company) => {
    setCurrentCompany(company);
    setShowForm(true);
  };

  const handleDeleteCompany = async (id) => {
    if (window.confirm('Are you sure you want to delete this company? This action cannot be undone.')) {
      try {
        await axios.delete(`/api/companies/${id}`);
        setCompanies(companies.filter(company => company._id !== id));
      } catch (error) {
        console.error('Error deleting company:', error);
        if (error.response && error.response.data && error.response.data.message) {
          setError(error.response.data.message);
        } else {
          setError('Failed to delete company');
        }
      }
    }
  };

  const handleFormSubmit = async (formData) => {
    try {
      if (currentCompany) {
        // Update existing company
        await axios.put(`/api/companies/${currentCompany._id}`, formData);
      } else {
        // Create new company
        await axios.post('/api/companies', formData);
      }
      
      // Refresh company list
      fetchCompanies();
      setShowForm(false);
    } catch (error) {
      console.error('Error saving company:', error);
      setError('Failed to save company');
    }
  };

  const handleFormCancel = () => {
    setShowForm(false);
  };

  // Only superadmin can access this page
  if (currentUser.role !== 'superadmin') {
    return (
      <div className="text-center py-10">
        <p className="text-red-500">You don't have permission to access this page.</p>
      </div>
    );
  }

  if (loading && companies.length === 0) {
    return (
      <div className="text-center py-10">
        <p className="text-gray-500">Loading companies...</p>
      </div>
    );
  }

  return (
    <div>
      <div className="mb-6 flex justify-between items-center">
        <div>
          <h1 className="text-2xl font-semibold text-gray-900">Companies</h1>
          <p className="mt-1 text-sm text-gray-500">
            Manage companies in the system
          </p>
        </div>
        <button
          onClick={handleAddCompany}
          className="btn-primary"
        >
          Add Company
        </button>
      </div>

      {error && (
        <div className="bg-red-50 border-l-4 border-red-500 p-4 mb-4">
          <div className="flex">
            <div className="ml-3">
              <p className="text-sm text-red-700">{error}</p>
            </div>
          </div>
        </div>
      )}

      {showForm ? (
        <CompanyForm
          company={currentCompany}
          onSubmit={handleFormSubmit}
          onCancel={handleFormCancel}
        />
      ) : (
        <div className="bg-white shadow overflow-hidden sm:rounded-md">
          {companies.length === 0 ? (
            <div className="text-center py-10">
              <p className="text-gray-500">No companies found. Add your first company!</p>
            </div>
          ) : (
            <ul className="divide-y divide-gray-200">
              {companies.map((company) => (
                <li key={company._id}>
                  <div className="px-4 py-4 sm:px-6">
                    <div className="flex items-center justify-between">
                      <div className="flex flex-col">
                        <p className="text-sm font-medium text-blue-600 truncate">{company.name}</p>
                        <p className="text-sm text-gray-500">
                          Created: {new Date(company.createdAt).toLocaleDateString()}
                        </p>
                      </div>
                      <div className="flex space-x-2">
                        <button
                          onClick={() => handleEditCompany(company)}
                          className="btn-secondary text-xs"
                        >
                          Edit
                        </button>
                        <button
                          onClick={() => handleDeleteCompany(company._id)}
                          className="btn-danger text-xs"
                        >
                          Delete
                        </button>
                      </div>
                    </div>
                  </div>
                </li>
              ))}
            </ul>
          )}
        </div>
      )}
    </div>
  );
}
