import { useState, useEffect } from 'react';
import axios from 'axios';

export default function UserForm({ 
  user, 
  companies, 
  currentUserRole, 
  currentUserCompanyId, 
  onSubmit, 
  onCancel 
}) {
  const [formData, setFormData] = useState({
    email: '',
    password: '',
    role: currentUserRole === 'superadmin' ? 'companyadmin' : 'employer',
    companyId: currentUserCompanyId || ''
  });
  const [errors, setErrors] = useState({});

  // If editing, populate form with user data
  useEffect(() => {
    if (user) {
      setFormData({
        email: user.email || '',
        password: '', // Don't populate password field for security
        role: user.role || '',
        companyId: user.companyId?._id || user.companyId || ''
      });
    }
  }, [user]);

  const handleChange = (e) => {
    const { name, value } = e.target;
    setFormData({
      ...formData,
      [name]: value
    });
  };

  const validateForm = () => {
    const newErrors = {};
    
    if (!formData.email.trim()) {
      newErrors.email = 'Email is required';
    } else if (!/\S+@\S+\.\S+/.test(formData.email)) {
      newErrors.email = 'Email is invalid';
    }
    
    if (!user && !formData.password) {
      newErrors.password = 'Password is required for new users';
    } else if (!user && formData.password.length < 6) {
      newErrors.password = 'Password must be at least 6 characters';
    }
    
    if (!formData.role) {
      newErrors.role = 'Role is required';
    }
    
    // Only validate company if role is not superadmin
    if (formData.role !== 'superadmin' && !formData.companyId) {
      newErrors.companyId = 'Company is required for non-superadmin users';
    }
    
    setErrors(newErrors);
    return Object.keys(newErrors).length === 0;
  };

  const handleSubmit = (e) => {
    e.preventDefault();
    
    if (validateForm()) {
      // If password is empty and editing, remove it from the form data
      const submitData = {...formData};
      if (user && !submitData.password) {
        delete submitData.password;
      }
      
      // If role is superadmin, remove companyId
      if (submitData.role === 'superadmin') {
        submitData.companyId = null;
      }
      
      console.log('Submitting user form data:', submitData);
      onSubmit(submitData);
    }
  };

  // Determine available roles based on current user's role
  const availableRoles = () => {
    if (currentUserRole === 'superadmin') {
      return [
        { value: 'superadmin', label: 'Super Admin' },
        { value: 'companyadmin', label: 'Company Admin' },
        { value: 'employer', label: 'Employer' }
      ];
    } else if (currentUserRole === 'companyadmin') {
      return [
        { value: 'employer', label: 'Employer' }
      ];
    }
    return [];
  };

  return (
    <div className="bg-white shadow sm:rounded-lg p-6">
      <h2 className="text-lg font-medium text-gray-900 mb-4">
        {user ? 'Edit User' : 'Add New User'}
      </h2>
      
      <form onSubmit={handleSubmit} className="space-y-6">
        <div>
          <label htmlFor="email" className="block text-sm font-medium text-gray-700">
            Email Address
          </label>
          <input
            type="email"
            name="email"
            id="email"
            value={formData.email}
            onChange={handleChange}
            className={`mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 sm:text-sm ${
              errors.email ? 'border-red-300' : ''
            }`}
          />
          {errors.email && <p className="mt-1 text-sm text-red-600">{errors.email}</p>}
        </div>

        <div>
          <label htmlFor="password" className="block text-sm font-medium text-gray-700">
            {user ? 'New Password (leave blank to keep current)' : 'Password'}
          </label>
          <input
            type="password"
            name="password"
            id="password"
            value={formData.password}
            onChange={handleChange}
            className={`mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 sm:text-sm ${
              errors.password ? 'border-red-300' : ''
            }`}
          />
          {errors.password && <p className="mt-1 text-sm text-red-600">{errors.password}</p>}
        </div>

        <div>
          <label htmlFor="role" className="block text-sm font-medium text-gray-700">
            Role
          </label>
          <select
            name="role"
            id="role"
            value={formData.role}
            onChange={handleChange}
            className={`mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 sm:text-sm ${
              errors.role ? 'border-red-300' : ''
            }`}
            disabled={user && currentUserRole === 'companyadmin'}
          >
            <option value="">Select a role</option>
            {availableRoles().map((role) => (
              <option key={role.value} value={role.value}>
                {role.label}
              </option>
            ))}
          </select>
          {errors.role && <p className="mt-1 text-sm text-red-600">{errors.role}</p>}
        </div>

        {/* Company selection - only for superadmin */}
        {currentUserRole === 'superadmin' ? (
          <div>
            <label htmlFor="companyId" className="block text-sm font-medium text-gray-700">
              Company
            </label>
            <select
              name="companyId"
              id="companyId"
              value={formData.companyId}
              onChange={handleChange}
              className={`mt-1 block w-full rounded-md border-gray-300 shadow-sm focus:border-blue-500 focus:ring-blue-500 sm:text-sm ${
                errors.companyId ? 'border-red-300' : ''
              }`}
            >
              <option value="">Select a company</option>
              {companies.map((company) => (
                <option key={company._id} value={company._id}>
                  {company.name}
                </option>
              ))}
            </select>
            {errors.companyId && <p className="mt-1 text-sm text-red-600">{errors.companyId}</p>}
          </div>
        ) : (
          <input type="hidden" name="companyId" value={currentUserCompanyId} />
        )}

        <div className="flex justify-end space-x-3">
          <button
            type="button"
            onClick={onCancel}
            className="btn-secondary"
          >
            Cancel
          </button>
          <button
            type="submit"
            className="btn-primary"
          >
            {user ? 'Update User' : 'Add User'}
          </button>
        </div>
      </form>
    </div>
  );
}
