import { useState, useEffect } from 'react';
import axios from 'axios';
import { useAuth } from '../../contexts/AuthContext';
import UserForm from './UserForm';

export default function Users() {
  const { currentUser } = useAuth();
  const [users, setUsers] = useState([]);
  const [companies, setCompanies] = useState([]);
  const [loading, setLoading] = useState(true);
  const [error, setError] = useState(null);
  const [showForm, setShowForm] = useState(false);
  const [currentUser_, setCurrentUser_] = useState(null);

  // Fetch users when component mounts
  useEffect(() => {
    if (currentUser && currentUser._id) {
      console.log('Current user in Users component:', currentUser);
      // Ensure axios has the token in its default headers
      const token = localStorage.getItem('token');
      if (token) {
        axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
      }
      
      fetchUsers();
      
      // If user is superadmin, fetch companies for the user form
      if (currentUser.role === 'superadmin') {
        fetchCompanies();
      }
    }
  }, [currentUser]);

  const fetchUsers = async () => {
    try {
      setLoading(true);
      
      // Ensure token is set in axios headers
      const token = localStorage.getItem('token');
      if (token) {
        axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
      }
      
      console.log('Fetching users with token:', token ? `${token.substring(0, 15)}...` : 'No token');
      const res = await axios.get('/api/users');
      console.log('Users response:', res.data);
      
      if (res.data && res.data.data) {
        setUsers(res.data.data);
        setError(null);
      } else {
        console.error('Unexpected response format:', res.data);
        setError('Invalid response format from server');
      }
    } catch (error) {
      console.error('Error fetching users:', error);
      if (error.response?.status === 401) {
        setError('Authentication failed. Please log in again.');
      } else {
        setError(error.response?.data?.message || 'Failed to load users');
      }
    } finally {
      setLoading(false);
    }
  };

  const fetchCompanies = async () => {
    try {
      // Ensure token is set in axios headers
      const token = localStorage.getItem('token');
      if (token) {
        axios.defaults.headers.common['Authorization'] = `Bearer ${token}`;
      }
      
      console.log('Fetching companies...');
      const res = await axios.get('/api/companies');
      console.log('Companies response:', res.data);
      
      if (res.data && res.data.data) {
        setCompanies(res.data.data);
      } else {
        console.error('Unexpected companies response format:', res.data);
        setError('Invalid companies response format from server');
      }
    } catch (error) {
      console.error('Error fetching companies:', error);
      setError(error.response?.data?.message || 'Failed to load companies');
    }
  };

  const handleAddUser = () => {
    setCurrentUser_(null);
    setShowForm(true);
  };

  const handleEditUser = (user) => {
    setCurrentUser_(user);
    setShowForm(true);
  };

  const handleDeleteUser = async (id) => {
    if (window.confirm('Are you sure you want to delete this user?')) {
      try {
        await axios.delete(`/api/users/${id}`);
        setUsers(users.filter(user => user._id !== id));
        setError(null);
      } catch (error) {
        console.error('Error deleting user:', error);
        setError(error.response?.data?.message || 'Failed to delete user');
      }
    }
  };

  const handleResetPassword = async (id) => {
    const newPassword = prompt('Enter new password (minimum 6 characters):');
    
    if (newPassword && newPassword.length >= 6) {
      try {
        await axios.put(`/api/users/${id}/reset-password`, { newPassword });
        alert('Password reset successful');
        setError(null);
      } catch (error) {
        console.error('Error resetting password:', error);
        setError(error.response?.data?.message || 'Failed to reset password');
      }
    } else if (newPassword) {
      alert('Password must be at least 6 characters');
    }
  };

  const handleFormSubmit = async (formData) => {
    try {
      if (currentUser_) {
        // Update existing user
        const response = await axios.put(`/api/users/${currentUser_._id}`, formData);
        console.log('User updated:', response.data);
      } else {
        // Create new user
        const response = await axios.post('/api/users', formData);
        console.log('User created:', response.data);
      }
      
      // Refresh user list
      fetchUsers();
      setShowForm(false);
      setError(null);
    } catch (error) {
      console.error('Error saving user:', error);
      if (error.response?.data?.message) {
        setError(error.response.data.message);
      } else if (error.response?.data?.errors && error.response.data.errors.length > 0) {
        setError(error.response.data.errors.map(err => err.msg).join(', '));
      } else {
        setError('Failed to save user');
      }
    }
  };

  const handleFormCancel = () => {
    setShowForm(false);
  };

  // Check if currentUser exists and has a role property
  if (!currentUser || !currentUser.role) {
    return (
      <div className="text-center py-10">
        <p className="text-red-500">Authentication error. Please log in again.</p>
      </div>
    );
  }
  
  // Only superadmin and companyadmin can access this page
  if (!['superadmin', 'companyadmin'].includes(currentUser.role)) {
    return (
      <div className="text-center py-10">
        <p className="text-red-500">You don't have permission to access this page.</p>
      </div>
    );
  }

  if (loading && users.length === 0) {
    return (
      <div className="text-center py-10">
        <p className="text-gray-500">Loading users...</p>
      </div>
    );
  }

  return (
    <div>
      <div className="mb-6 flex justify-between items-center">
        <div>
          <h1 className="text-2xl font-semibold text-gray-900">Users</h1>
          <p className="mt-1 text-sm text-gray-500">
            Manage users in the system
          </p>
        </div>
        <button
          onClick={handleAddUser}
          className="btn-primary"
        >
          Add User
        </button>
      </div>

      {error && (
        <div className="bg-red-50 border-l-4 border-red-500 p-4 mb-4">
          <div className="flex">
            <div className="ml-3">
              <p className="text-sm text-red-700">{error}</p>
            </div>
          </div>
        </div>
      )}

      {showForm ? (
        <UserForm
          user={currentUser_}
          companies={companies}
          currentUserRole={currentUser.role}
          currentUserCompanyId={currentUser.companyId}
          onSubmit={handleFormSubmit}
          onCancel={handleFormCancel}
        />
      ) : (
        <div className="bg-white shadow overflow-hidden sm:rounded-md">
          {users.length === 0 ? (
            <div className="text-center py-10">
              <p className="text-gray-500">No users found. Add your first user!</p>
            </div>
          ) : (
            <ul className="divide-y divide-gray-200">
              {users.map((user) => (
                <li key={user._id}>
                  <div className="px-4 py-4 sm:px-6">
                    <div className="flex items-center justify-between">
                      <div className="flex flex-col">
                        <p className="text-sm font-medium text-blue-600 truncate">{user.email}</p>
                        <div className="flex space-x-2 mt-1">
                          <span className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-blue-100 text-blue-800">
                            {user.role}
                          </span>
                          {user.companyId && (
                            <span className="inline-flex items-center px-2.5 py-0.5 rounded-full text-xs font-medium bg-gray-100 text-gray-800">
                              {typeof user.companyId === 'object' ? user.companyId.name : 'Company ID: ' + user.companyId}
                            </span>
                          )}
                        </div>
                      </div>
                      <div className="flex space-x-2">
                        <button
                          onClick={() => handleResetPassword(user._id)}
                          className="text-xs px-3 py-1 bg-yellow-100 text-yellow-800 rounded-md hover:bg-yellow-200"
                        >
                          Reset Password
                        </button>
                        <button
                          onClick={() => handleEditUser(user)}
                          className="btn-secondary text-xs"
                        >
                          Edit
                        </button>
                        <button
                          onClick={() => handleDeleteUser(user._id)}
                          className="btn-danger text-xs"
                        >
                          Delete
                        </button>
                      </div>
                    </div>
                  </div>
                </li>
              ))}
            </ul>
          )}
        </div>
      )}
    </div>
  );
}
